.header-wrapper {
  display: flex;
  padding: 20px 0 10px;
  align-items: center;
}

.header-wrapper h1 {
  margin: 0;
}

.header-wrapper a {
  margin: 5px 0 0 20px;
  font-size: 24px;
  flex-basis: auto;
  align-self: center;
}

.toggle-arrow {
  cursor: pointer;
  width: 0;
  height: 0;
  border-left: 5px solid transparent;
  border-right: 5px solid transparent;
  border-top: 10px solid #337ab7;
  display: inline-block;
  transition: transform 0.3s;
}

.toggle-arrow:hover {
  border-top-color: #23527c;
}

.toggle-arrow-open {
  transform: rotate(180deg);
}
