.meta-item {
    clear: both;
    margin: 15px 0px;
}

.meta-item label {
    margin-right: 30px;
    float: left;
}

.node-create input {
    margin-left: 10px;
}

.node-create select {
    margin: 0px 0px 0px 10px;
    width: 300px;
}

.node-create form {
    clear: both;
}
