export default {
  textInput: {
    border: '2px solid rgb(204, 204, 204)',
    borderRadius: '4px',
    fontFamily: 'Open Sans',
    fontSize: '14px',
    lineHeight: 1.1,
    color: 'rgb(51, 51, 51)',
    padding: '6px 0px 8px 16px'
  }
};
