{% extends 'admin/_pool_info_base.html' %}

{% block content_menu %}
  {% include "admin/_pool_navbar.html" with active="info" %}
{% endblock %}

{% block content_body %}
  {% include "admin/_pool_nodes.html" %}
{% endblock %}
