{% extends "base.html" %}
{% load staticfiles %}

{% block extra_css %}
{{ block.super }}
<link rel="stylesheet" href="{% static "css/metrics/components/metrics.legacy.css" %}">
<link rel="stylesheet" href="{% static "css/pages/node-info.css" %}">
{% endblock %}

{% block sidebar %}
{% include "sidebar.html" with active="docker" %}
{% endblock %}

{% block bar %}
<div class="bar">
  <a href="/">dashboard</a> <span class="arrow">></span>
  <a href="{% url 'pool-list' %}">hosts</a> <span class="arrow">></span>
    node info
</div>
{% endblock %}

{% block content %}
<div class="container-fluid">
    <div class="row">
      <div class="col-md-12" id="node-info"></div>
    </div>
</div>

<script type="application/json" id="django-settings">
 {"ELASTICSEARCH_METRICS_ENABLED": {% if settings.ELASTICSEARCH_METRICS_ENABLED %}true{%else %}false{% endif %}}
</script>
{% endblock %}

{% block extra_js %}
<script src="{% static "js/vendor/jquery.flot.min.js" %}"></script>
<script src="{% static "js/vendor/jquery.flot.time.min.js" %}"></script>
<script src="{% static "js/vendor/jquery.flot.tooltip.min.js" %}"></script>
<script src="{% static "js/pages/node-info.js" %}"></script>
{% endblock %}
