{% extends "apps/base.html" %}
{% load filters_deploys %}
{% load staticfiles %}

{% block extra_css %}
{{ block.super }}
{% include "events/list/_css.html" %}
{% endblock %}

{% block navbar %}
{% include "apps/navbar.html" with active="events" %}
{% endblock %}

{% block app-content %}
{% include "events/list/_content.html" %}
{% endblock %}

{% block extra_js %}
{% include "events/list/_js.html" %}
{% endblock %}
