{% extends "base.html" %}
{% load staticfiles %}

{% block extra_css %}
<style>
table td, table th {
  min-width: 200px;
  overflow: hidden;
  display: inline-block;
  white-space: nowrap;
}
.pool-header {
  display: inline-block;
  margin-right: 10px;
}
</style>
{% endblock %}

{% block sidebar %}
{% include "sidebar.html" with active="docker" %}
{% endblock %}

{% block bar %}
<div class="bar">
  <a href="/">dashboard</a> <span class="arrow">></span>
  hosts
</div>
{% endblock %}

{% block header %}
<h1>Admin/Nodes</h1>
{% endblock %}

{% block content %}
<div class="container-fluid">
  {% for pool in pools %}
  <div class="row">
    <div class="pool-list col-md-12" data-pool-name="{{ pool.0 }}" data-nodes="{{ pool.1 }}">
    </div>
  </div>
  {% endfor %}
</div>
{% endblock %}

{% block extra_js %}
<script src="{% static "js/pages/pool-list.js" %}"></script>
{% endblock %}
