{% extends "apps/base.html" %}
{% load staticfiles %}
{% load filters_deploys %}

{% block extra_css %}
{{ block.super }}
{% include "events/info/_css.html" %}
{% endblock %}

{% block navbar %}
{% include "apps/navbar.html" with active="events" %}
{% endblock %}

{% block app-content %}
<div class="row">
  <div class="col-md-12">
    <h3>Info</h3>
    {% include "events/info/_content.html" %}
  </div>
</div>
{% endblock %}

{% block extra_js %}
{% include "events/info/_js.html" %}
{% endblock %}
