{% extends "base.html" %}
{% load staticfiles %}

{% block extra_css %}
  <link rel="stylesheet" href="{% static "css/pool-rebalance.css" %}" />
  <link rel="stylesheet" href="{% static "css/pages/node-create.css" %}">
{% endblock %}

{% block sidebar %}
  {% include "sidebar.html" with active="docker" %}
{% endblock %}

{% block header %}
  <h1>Admin/Nodes - {{ pool }}</h1>
{% endblock %}

{% block bar %}
  <div class="bar">
    <a href="/">dashboard</a> <span class="arrow">></span>
    <a href="{% url 'pool-list' %}">hosts</a> <span class="arrow">></span>
    {{ pool }}
  </div>
{% endblock %}

{% block content %}
  <div class="container-fluid">
    <div class="col-md-12">
      <ul class="nav nav-tabs">
        {% block content_menu %}{% endblock %}
      </ul>
    </div>
    <div class="col-md-12">
      <div id="node-create"
           class="modal fade"
           tabindex="-1"
           role="dialog"
           aria-labelledby="myModalLabel"
           aria-hidden="true">
      </div>
    </div>
    {% block content_body %}{% endblock %}
  </div>

  <div
      id="pool-rebalance"
      class="modal fade"
      tabindex="-1"
      role="dialog"
      data-keyboard="false"
      data-backdrop="static"
      aria-labelledby="myModalLabel"
      aria-hidden="true"
      data-url="{% url "pool-rebalance" pool %}"
      data-poolname="{{ pool }}">
  </div>

{% endblock %}

{% block extra_js %}
  <script src="{% static "js/pages/pool-rebalance.js" %}"></script>
  <script src="{% static "js/pages/pool-info.js" %}"></script>
{% endblock %}
